import os
import base64
import sampleprojectdef

__author__ = 'Maruf Maniruzzaman'

def new_project(path):
    file_data_list = sampleprojectdef.file_data_list
    for file_data in file_data_list:
        filename = file_data["name"]
        data = file_data["data"]
        if filename[0]=='/':
            filename = filename[1:]
        file_path = os.path.join(path, filename)
        dir_name = os.path.dirname(file_path)
        if not os.path.exists(dir_name):
            os.makedirs(dir_name)
        with open(file_path, 'w') as content_file:
            content_file.write(data)

if __name__ == "__main__":
    path = os.getcwd()
    new_project(path)




import os
import base64

__author__ = 'maruf'



def get_files(rootdir, exclude="local_settings.py"):
    file_list = []
    for root, subFolders, files in os.walk(rootdir):
        files = [ file for file in files if not file.endswith( ('.pyc','.tar') ) ]
        for filename in files:
            if filename == exclude:
                continue
            filePath = os.path.join(root, filename)
            file_list.append(filePath)

    return file_list


if __name__ == "__main__":
    path = os.path.abspath(os.path.join(os.path.dirname(os.path.realpath(__file__)), "../../sampleprj"))
    print "Packaging application from [{0}]".format(path)
    file_list = get_files(path)
    root_len = len(path)
    file_data_list = []
    for filename in file_list:
        relative = filename[root_len:]
        print filename, " ", relative

        with open(filename, 'r') as content_file:
            content = content_file.read()
            file_data = {"name": relative, "data": content}
            file_data_list.append(file_data)

    sample_def_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "sampleprojectdef.py")
    print sample_def_path

    with open(sample_def_path, 'w') as content_file:
        content_file.write("import base64\n\n")
        content_file.write("file_data_list=[\n")
        first = True
        for file_data in file_data_list:
            if not first:
                content_file.write(",\n")
            first = False
            content_file.write("{\n")
            name = file_data["name"]
            content_file.write("'name': '{0}', ".format(name))
            data = base64.b64encode(file_data["data"])
            content_file.write("'data': base64.b64decode('{0}')".format(data))
            content_file.write("\n}")

        content_file.write("]\n")



__author__ = 'Maruf Maniruzzaman'

import os
import sys
import logging
import getpass
import createproject

from cosmos.dataservice.objectservice import *

class CommandHandler():
    def __init__(self, *args, **kwargs):
        self.db = kwargs.get("db", None)

    def handle_command(self, *args, **kwarg):
        current_directory = args[0]
        command = args[1]
        print command

        if command == "new-admin":
            self.create_admin_user()
            return
        if command == "add-herokusettings":
            add_heroku_settings(current_directory)
            sys.exit(0)
        elif command == "new-project":
            createproject.new_project(current_directory)
            sys.exit(0)
        else:
            print "Unknown command"
            sys.exit(0)

    def get_input(self, prompt):
        input = None
        while not input or len(input)==0:
            input = raw_input(prompt).strip()

        return input

    def _admin_user_created(self, result, error):
        if error:
            logging.error("Admin user creation failed.")
            logging.error(error)
        else:
            logging.info("Admin user was created successfully.")

        sys.exit(0)

    def create_admin_user(self):
        username = self.get_input('Enter admin username: ')
        password = getpass.getpass('Enter admin password: ')
        password_re = getpass.getpass('Repeat admin password: ')
        if password != password_re:
            print "Password mismatch"
            sys.exit(1)

        email = self.get_input('Enter admin email: ')
        data = {"username":username, "password":password, "email":email, "roles":[ADMIN_USER_ROLE_SID]}
        object_service = ObjectService()
        object_service.save(SYSTEM_USER, self.db, COSMOS_USERS_OBJECT_NAME, data, self._admin_user_created)

def add_heroku_settings(current_directory):
    proc_file_path = os.path.join(current_directory, "Procfile")
    with open(proc_file_path, 'w') as procfile:
            procfile.write("web: python cosmosmain.py start-service $PORT")
    req_file_path = os.path.join(current_directory, "requirements.txt")

    with open(req_file_path, 'w') as req_file:
            req_file.write("cosmos")


def admin_main():
    current_directory = os.getcwd()
    if len(sys.argv) < 1:
        print "Command required"
        return
    else:
        command = sys.argv[1].strip()
        handler = CommandHandler()
        handler.handle_command(current_directory, command)

    tornado.ioloop.IOLoop.instance().start()
